==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/en/csv2xtHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "csvxmlTablؤѴ"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-F*/
#define HFDT "ܤ̾Ȥߤʤ"
#define HFDC "csvեΰܤ̾ȤxmlTableΥإå˼"

/*-a*/
#define FNMT "̾ꥹ"
#define FNMC "ǻꤷ̾ꥹȤxmlTableΥإåϿ"

/*-l*/
#define TITT "ȥ"
#define TITC "ǻꤷȥxmlTableΥإåϿ"

/*-c*/
#define COMT ""
#define COMC "ǻꤷȤxmlTableΥإåϿ"

/*-s*/
#define SPCT "ʸ"
#define SPCC "ƥΥڡɤʸ֤뤫ꤹ"

/*-I*/
#define IMPT "ݡȥե̾"
#define IMPC "إå򥤥ݡȤΥإåxmlTableΥإåϿ"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "csvxmlTableѴ"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
  csv2xt -F -i dat.txt -o rsl.xt\n\
  csv2xt -aܵҥ,,,, -i dat.txt -o rls.xt\n\
  csv2xt -F -i dat.txt -l ץǡ -c ޥ˥奢Ѥ˺ -o rsl.xt\n\
  csv2xt -I header.xt -i dat.txt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "txt2xt,xt2txt,xt2xml,xml2xt"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre3.tar.gz: musashi-core-1.0.4-pre3/help/en/csv2xtHelp.h <==
#include "commonHelp.h"
/*============================================================================*/
/* management of messages common to command help, man, and musahi GUI         */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* Command title                                                              */
/* Indicate at the first line of command helpޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "Conversion from csv to xmlTabl"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-F*/
#define HFDT "Regard the first line as a list of attribute names"
#define HFDC "Regarding the first line of a csv file as a list of attribute names,  it is included  into a header of an xmlTable."

/*-a*/
#define FNMT "A list of new attribute names"
#define FNMC "Register the list of attribute names specified here into a header of an xmlTable."

/*-l*/
#define TITT "Title"
#define TITC "Register the title specified here into a header of an xmlTable"

/*-c*/
#define COMT "Comment"
#define COMC "Register the comment specified here into a header of an xmlTable"

/*-s*/
#define SPCT "Replaced character for a space"
#define SPCC "Specify the character string by which a space in the text is replaced. Default is _."

/*-I*/
#define IMPT "The header file name to be imported"
#define IMPC "Import the header, and regsiter its information into a header of an xmlTable"

/*-f*/
#define FRCT "ܿΡå"
#define FRCC "ܿΥå򤪤ʤʤإåιܿ˹碌ƽ롣"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "Convert a csv file into an xmlTable file"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
  csv2xt -F -i dat.txt -o rsl.xt\n\
  csv2xt -a customerID,date,goods,quantity,amount -i dat.txt -o rls.xt\n\
  csv2xt -F -i dat.txt -l sample_data -c create as a manual -o rsl.xt\n\
  csv2xt -I header.xt -i dat.txt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "txt2xt,xt2txt,xt2xml,xml2xt"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
